@@ -102,7 +102,6 @@ class Blocker(object):
         self.conn = None
         self.conn_params = (host, port, db)
         self.callbacks = {}
-        self.ttls = {}
         self.state_ok = False
         self.reconnect(*self.conn_params)
 
@@ -124,13 +123,17 @@ class Blocker(object):
             callback = self.callbacks[key]
             callback(data[1])
             del self.callbacks[key]
-            del self.ttls[key]
 
 
-    def blpop(self, key, callback, timeout=300):
+    def blpop(self, key, callback, timeout=60):
         self.callbacks[key] = callback
-        self.ttls[key] = time.time()
-        self.conn.write(parse_command("blpop", key, timeout))
+        try:
+            self.conn.write(parse_command("blpop", key, timeout))
+        except Exception, e:
+            logging.error(str(e))
+            self.reconnect(*self.conn_params)
+            callback({})
+            del self.callbacks[key]
 
 
 class Subscriber(object):
